==> haskell-criterion-measurement-0.1.1.0-7-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-criterion-measurement.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: criterion-measurement
version: 0.1.1.0
id: criterion-measurement-0.1.1.0-A4IDCGe5mYI5kHpGs9GYEZ
key: criterion-measurement-0.1.1.0-A4IDCGe5mYI5kHpGs9GYEZ
license: BSD-3-Clause
copyright: 2009-2016 Bryan O'\''Sullivan and others
maintainer: Marco Zocca <zocca.marco gmail>, Ryan Scott <ryan.gl.scott@gmail.com>
author: Bryan O'\''Sullivan <bos@serpentine.com>
homepage: https://github.com/bos/criterion
synopsis: Criterion measurement functionality and associated types
description:
    Measurement-related functionality extracted from Criterion, with minimal dependencies. The rationale for this is to enable alternative analysis front-ends.
category: Development, Performance, Testing, Benchmarking
abi: fa0b51e5bb23de4f9792a446fc6bc8c9
exposed: True
exposed-modules:
    Criterion.Measurement Criterion.Measurement.Types
    Criterion.Measurement.Types.Internal
import-dirs: /usr/lib/ghc-8.4.3/site-local/criterion-measurement-0.1.1.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/criterion-measurement-0.1.1.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/criterion-measurement-0.1.1.0
hs-libraries: HScriterion-measurement-0.1.1.0-A4IDCGe5mYI5kHpGs9GYEZ
depends:
    aeson-1.4.0.0-9WkSvHx7LJ453dlLjxz2kL base-4.11.1.0
    base-compat-0.10.4-9FtFg9E90S5CFRyvxjUaaZ binary-0.8.5.1
    containers-0.5.11.0 deepseq-1.4.3.0
    vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq
abi-depends: aeson-1.4.0.0-9WkSvHx7LJ453dlLjxz2kL=912860ab3519756596367ddae154025c
             base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             base-compat-0.10.4-9FtFg9E90S5CFRyvxjUaaZ=d7511a9b0b5b14c2ec3659e1cd285aec
             binary-0.8.5.1=0c28e4e382bf1405fd468e0d2a2b58e5
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             deepseq-1.4.3.0=34da2d42d10eacba0aad99c95b538637
             vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq=8ec9732a4c43da9ed60d7a7b8971b540
haddock-interfaces: /usr/share/doc/haskell-criterion-measurement/html/criterion-measurement.haddock
haddock-html: /usr/share/doc/haskell-criterion-measurement/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-criterion-measurement-0.1.1.0-9-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-criterion-measurement.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: criterion-measurement
version: 0.1.1.0
id: criterion-measurement-0.1.1.0-AFj7zvAmftqDknVfmIIWCz
key: criterion-measurement-0.1.1.0-AFj7zvAmftqDknVfmIIWCz
license: BSD-3-Clause
copyright: 2009-2016 Bryan O'\''Sullivan and others
maintainer: Marco Zocca <zocca.marco gmail>, Ryan Scott <ryan.gl.scott@gmail.com>
author: Bryan O'\''Sullivan <bos@serpentine.com>
homepage: https://github.com/bos/criterion
synopsis: Criterion measurement functionality and associated types
description:
    Measurement-related functionality extracted from Criterion, with minimal dependencies. The rationale for this is to enable alternative analysis front-ends.
category: Development, Performance, Testing, Benchmarking
abi: 9d97a4a4127d7153f6adafa6dc098cb1
exposed: True
exposed-modules:
    Criterion.Measurement Criterion.Measurement.Types
    Criterion.Measurement.Types.Internal
import-dirs: /usr/lib/ghc-8.4.3/site-local/criterion-measurement-0.1.1.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/criterion-measurement-0.1.1.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/criterion-measurement-0.1.1.0
hs-libraries: HScriterion-measurement-0.1.1.0-AFj7zvAmftqDknVfmIIWCz
depends:
    aeson-1.4.1.0-GPUdiNXlyQm9pSbB9CFKk6 base-4.11.1.0
    base-compat-0.10.4-9FtFg9E90S5CFRyvxjUaaZ binary-0.8.5.1
    containers-0.5.11.0 deepseq-1.4.3.0
    vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq
abi-depends: aeson-1.4.1.0-GPUdiNXlyQm9pSbB9CFKk6=22145541f26b56c63b48572ec79b9cbd
             base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             base-compat-0.10.4-9FtFg9E90S5CFRyvxjUaaZ=d7511a9b0b5b14c2ec3659e1cd285aec
             binary-0.8.5.1=0c28e4e382bf1405fd468e0d2a2b58e5
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             deepseq-1.4.3.0=34da2d42d10eacba0aad99c95b538637
             vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq=8ec9732a4c43da9ed60d7a7b8971b540
haddock-interfaces: /usr/share/doc/haskell-criterion-measurement/html/criterion-measurement.haddock
haddock-html: /usr/share/doc/haskell-criterion-measurement/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
